===================================
Generate New Python Package Project
===================================

This *python generator* was designed to be installed via *pip* and then invoked through
the cli.

------------------
Installing the cli
------------------

.. include:: installation.rst

-------------
Using the cli
-------------

.. include:: generate_project.rst


.. _Use Cases:

============================
New Python Package Use Cases
============================

.. include:: use_cases.rst
